function [] = autosave(filename, ext, folder)
% [] = autosave()
% Function saves all figures with name 'filename_STAMP.ext' into specified folder (default 'img').
% ext is specified file extension (default 'fig') and STAMP is as:
% 'yymmdd_HHMM_FFF' where 'yy' is year, 'mm' month, 'dd' day, 'HH' hours,
% 'MM' minutes, 'FFF' miliseconds.
% INPUT:
%  filename (string) ... filename of files
%     default: 'unknown'
%  ext (string) ... extension of file (file format)
%     default: 'fig'
%  folder (string) ... folder for saving files
%     default: 'img'
% OUTPUT:
%  saved files
%
% Author: Jan Kohout, jankoweb(at)volny.cz, 2011
% Version: 1.0, 20.11.2011, 12:00
%

if (nargin < 3)
    folder = 'img';
end
if (nargin < 2)
    ext = 'fig';
end
if (nargin < 1)
    filename = 'unknown';
end

if (~isdir(folder))
   mkdir(folder);
end

% list of figures
list_hf = get(0, 'children');

disp('Saving figures. Wait please...')
for m = 1:length(list_hf)
    saveas(list_hf(m), ['./' folder '/' filename '_' datestr(now,'yymmdd_HHMM_FFF') '.' ext]) 
end

% result
disp(['All figures saved into folder "' folder '" as'])
disp([filename '_yymmdd_HHMM_FFF.' ext])
